@@ -21,7 +21,6 @@ from gene import ITEM_TYPES, NAMESPACE_LOOKUP, PREFIX_LOOKUP, __version__
 from gene.database import AbstractDatabase, DatabaseReadException
 from gene.schemas import (
     NAMESPACE_TO_SYSTEM_URI,
-    SYSTEM_URI_TO_NAMESPACE,
     BaseGene,
     BaseNormalizationService,
     Gene,
@@ -168,9 +167,9 @@ class QueryHandler:
         """
         try:
             match = self.db.get_record_by_id(concept_id, case_sensitive=False)
-        except DatabaseReadException as e:
-            _logger.error(
-                "Encountered DatabaseReadException looking up %s: %s", concept_id, e
+        except DatabaseReadException:
+            _logger.exception(
+                "Encountered DatabaseReadException looking up %s", concept_id
             )
         else:
             if match:
@@ -244,12 +243,11 @@ class QueryHandler:
                             self._fetch_record(resp, ref, MatchType[item_type.upper()])
                             matched_concept_ids.append(ref)
 
-            except DatabaseReadException as e:
-                _logger.error(
+            except DatabaseReadException:
+                _logger.exception(
                     "Encountered DatabaseReadException looking up %s %s: ",
                     item_type,
                     term,
-                    e,
                 )
                 continue
 
@@ -348,10 +346,13 @@ class QueryHandler:
 
         sources = []
         for m in gene.mappings or []:
-            ns = SYSTEM_URI_TO_NAMESPACE.get(m.coding.system)
+            ns = m.coding.id.split(":")[0]
             if ns in PREFIX_LOOKUP:
                 sources.append(PREFIX_LOOKUP[ns])
 
+        # Add metadata for primaryCoding id
+        sources.append(PREFIX_LOOKUP[gene.primaryCoding.id.split(":")[0]])
+
         for src in sources:
             if src not in sources_meta:
                 _source_meta = self.db.get_source_metadata(src)
@@ -401,21 +402,17 @@ class QueryHandler:
         :return: Response with core Gene
         """
 
-        def _create_concept_mapping(
-            concept_id: str, relation: Relation = Relation.RELATED_MATCH
-        ) -> ConceptMapping:
-            """Create concept mapping for identifier
+        def _get_coding_object(concept_id: str) -> Coding:
+            """Get coding object for CURIE identifier
 
-            ``system`` will use source homepage or namespace prefix, in that order of \
-            preference, if available.
+            ``system`` will use system prefix URL or system homepage
 
             :param concept_id: A lowercase concept identifier represented as a curie
-            :param relation: SKOS mapping relationship, default is relatedMatch
+            :return: Coding object for identifier
             :raises ValueError: If source of concept ID is not a valid
                 ``NamespacePrefix``
-            :return: Concept mapping for identifier
             """
-            source, source_id = concept_id.split(":")
+            source, source_code = concept_id.split(":")
 
             try:
                 source = NamespacePrefix(source)
@@ -423,28 +420,48 @@ class QueryHandler:
                 err_msg = f"Namespace prefix not supported: {source}"
                 raise ValueError(err_msg) from e
 
-            system = NAMESPACE_TO_SYSTEM_URI.get(source, source)
-            code_ = concept_id.upper() if source == NamespacePrefix.HGNC else source_id
+            if source == NamespacePrefix.HGNC:
+                source_code = concept_id.upper()
 
+            return Coding(
+                id=concept_id,
+                code=code(source_code),
+                system=NAMESPACE_TO_SYSTEM_URI[source],
+            )
+
+        def _get_concept_mapping(
+            concept_id: str, relation: Relation = Relation.RELATED_MATCH
+        ) -> ConceptMapping:
+            """Get concept mapping for Coding object
+
+            :param concept_id: A lowercase concept identifier represented as a curie
+            :param relation: SKOS mapping relationship, default is relatedMatch
+            :return: Concept mapping for identifier
+            """
             return ConceptMapping(
-                coding=Coding(code=code(code_), system=system), relation=relation
+                coding=_get_coding_object(concept_id),
+                relation=relation,
             )
 
         gene_obj = MappableConcept(
             id=f"normalize.gene.{record['concept_id']}",
-            primaryCode=code(root=record["concept_id"]),
-            label=record["symbol"],
+            primaryCoding=_get_coding_object(record["concept_id"]),
+            name=record["symbol"],
             conceptType="Gene",
         )
 
-        # mappings
-        mappings = [
-            _create_concept_mapping(record["concept_id"], relation=Relation.EXACT_MATCH)
+        xrefs = [record["concept_id"], *record.get("xrefs", [])]
+        gene_obj.mappings = [
+            _get_concept_mapping(xref_id, relation=Relation.EXACT_MATCH)
+            for xref_id in xrefs
+            if xref_id != record["concept_id"]
         ]
-        source_ids = record.get("xrefs", []) + record.get("associated_with", [])
-        mappings.extend(_create_concept_mapping(source_id) for source_id in source_ids)
-        if mappings:
-            gene_obj.mappings = mappings
+
+        associated_with = record.get("associated_with", [])
+        gene_obj.mappings.extend(
+            _get_concept_mapping(associated_with_id, relation=Relation.RELATED_MATCH)
+            for associated_with_id in associated_with
+        )
 
         # extensions
         extensions = []
@@ -556,7 +573,7 @@ class QueryHandler:
         >>> from gene.database import create_db
         >>> q = QueryHandler(create_db())
         >>> result = q.normalize("BRAF")
-        >>> result.gene.primaryCode.root
+        >>> result.gene.primaryCoding.id
         'hgnc:1097'
         >>> next(ext for ext in result.gene.extensions if ext.name == "aliases").value
         ['BRAF1', 'RAFB1', 'B-raf', 'NS7', 'B-RAF1']
