@@ -34,80 +34,90 @@ def normalized_ache():
     params = {
         "conceptType": "Gene",
         "id": "normalize.gene.hgnc:108",
-        "primaryCode": "hgnc:108",
-        "label": "ACHE",
+        "primaryCoding": {
+            "id": "hgnc:108",
+            "code": "HGNC:108",
+            "system": "https://www.genenames.org/data/gene-symbol-report/#!/hgnc_id/",
+        },
+        "name": "ACHE",
         "mappings": [
             {
                 "coding": {
-                    "code": "HGNC:108",
-                    "system": "https://www.genenames.org",
+                    "id": "ensembl:ENSG00000087085",
+                    "code": "ENSG00000087085",
+                    "system": "https://www.ensembl.org/id/",
                 },
                 "relation": "exactMatch",
             },
             {
                 "coding": {
-                    "code": "ENSG00000087085",
-                    "system": "https://www.ensembl.org",
-                },
-                "relation": "relatedMatch",
-            },
-            {
-                "coding": {
+                    "id": "ncbigene:43",
                     "code": "43",
                     "system": "https://www.ncbi.nlm.nih.gov/gene/",
                 },
-                "relation": "relatedMatch",
+                "relation": "exactMatch",
             },
             {
                 "coding": {
+                    "id": "vega:OTTHUMG00000157033",
                     "code": "OTTHUMG00000157033",
-                    "system": "https://www.sanger.ac.uk/tool/vega-genome-browser/",
+                    "system": "https://vega.archive.ensembl.org/Homo_sapiens/Gene/Summary?g=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "ucsc:uc003uxi.4",
                     "code": "uc003uxi.4",
-                    "system": "https://genome.ucsc.edu",
+                    "system": "http://genome.cse.ucsc.edu/cgi-bin/hgGene?org=Human&hgg_chrom=none&hgg_type=knownGene&hgg_gene=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "uniprot:P22303",
                     "code": "P22303",
-                    "system": "https://www.uniprot.org",
+                    "system": "http://purl.uniprot.org/uniprot/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "pubmed:1380483",
                     "code": "1380483",
-                    "system": "https://pubmed.ncbi.nlm.nih.gov",
+                    "system": "https://pubmed.ncbi.nlm.nih.gov/",
                 },
                 "relation": "relatedMatch",
             },
             {
-                "coding": {"code": "100740", "system": "https://www.omim.org"},
+                "coding": {
+                    "id": "omim:100740",
+                    "code": "100740",
+                    "system": "https://www.omim.org/MIM:",
+                },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "merops:S09.979",
                     "code": "S09.979",
-                    "system": "https://www.ebi.ac.uk/merops/",
+                    "system": "https://www.ebi.ac.uk/merops/cgi-bin/pepsum?id=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "iuphar:2465",
                     "code": "2465",
-                    "system": "https://www.guidetopharmacology.org",
+                    "system": "https://www.guidetopharmacology.org/GRAC/ObjectDisplayForward?objectId=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "refseq:NM_015831",
                     "code": "NM_015831",
-                    "system": "https://www.ncbi.nlm.nih.gov/refseq/",
+                    "system": "https://www.ncbi.nlm.nih.gov/nuccore/",
                 },
                 "relation": "relatedMatch",
             },
@@ -166,98 +176,114 @@ def normalized_braf():
     params = {
         "conceptType": "Gene",
         "id": "normalize.gene.hgnc:1097",
-        "primaryCode": "hgnc:1097",
-        "label": "BRAF",
+        "primaryCoding": {
+            "id": "hgnc:1097",
+            "code": "HGNC:1097",
+            "system": "https://www.genenames.org/data/gene-symbol-report/#!/hgnc_id/",
+        },
+        "name": "BRAF",
         "mappings": [
             {
                 "coding": {
-                    "code": "HGNC:1097",
-                    "system": "https://www.genenames.org",
+                    "id": "ncbigene:673",
+                    "code": "673",
+                    "system": "https://www.ncbi.nlm.nih.gov/gene/",
                 },
                 "relation": "exactMatch",
             },
             {
                 "coding": {
-                    "code": "673",
-                    "system": "https://www.ncbi.nlm.nih.gov/gene/",
-                },
-                "relation": "relatedMatch",
-            },
-            {
-                "coding": {
+                    "id": "ensembl:ENSG00000157764",
                     "code": "ENSG00000157764",
-                    "system": "https://www.ensembl.org",
+                    "system": "https://www.ensembl.org/id/",
                 },
-                "relation": "relatedMatch",
+                "relation": "exactMatch",
             },
             {
                 "coding": {
+                    "id": "iuphar:1943",
                     "code": "1943",
-                    "system": "https://www.guidetopharmacology.org",
+                    "system": "https://www.guidetopharmacology.org/GRAC/ObjectDisplayForward?objectId=",
                 },
                 "relation": "relatedMatch",
             },
             {
-                "coding": {"code": "119066", "system": "orphanet"},
+                "coding": {
+                    "id": "orphanet:119066",
+                    "code": "119066",
+                    "system": "http://www.orpha.net/consor/cgi-bin/OC_Exp.php?Lng=EN&Expert=",
+                },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "cosmic:BRAF",
                     "code": "BRAF",
-                    "system": "https://cancer.sanger.ac.uk/cosmic/",
+                    "system": "http://cancer.sanger.ac.uk/cosmic/gene/overview?ln=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "pubmed:2284096",
                     "code": "2284096",
-                    "system": "https://pubmed.ncbi.nlm.nih.gov",
+                    "system": "https://pubmed.ncbi.nlm.nih.gov/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "ucsc:uc003vwc.5",
                     "code": "uc003vwc.5",
-                    "system": "https://genome.ucsc.edu",
+                    "system": "http://genome.cse.ucsc.edu/cgi-bin/hgGene?org=Human&hgg_chrom=none&hgg_type=knownGene&hgg_gene=",
                 },
                 "relation": "relatedMatch",
             },
             {
-                "coding": {"code": "164757", "system": "https://www.omim.org"},
+                "coding": {
+                    "id": "omim:164757",
+                    "code": "164757",
+                    "system": "https://www.omim.org/MIM:",
+                },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "refseq:NM_004333",
                     "code": "NM_004333",
-                    "system": "https://www.ncbi.nlm.nih.gov/refseq/",
+                    "system": "https://www.ncbi.nlm.nih.gov/nuccore/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "uniprot:P15056",
                     "code": "P15056",
-                    "system": "https://www.uniprot.org",
+                    "system": "http://purl.uniprot.org/uniprot/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "ena.embl:M95712",
                     "code": "M95712",
-                    "system": "https://www.ebi.ac.uk/ena/",
+                    "system": "https://www.ebi.ac.uk/ena/browser/view/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "vega:OTTHUMG00000157457",
                     "code": "OTTHUMG00000157457",
-                    "system": "https://www.sanger.ac.uk/tool/vega-genome-browser/",
+                    "system": "https://vega.archive.ensembl.org/Homo_sapiens/Gene/Summary?g=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "pubmed:1565476",
                     "code": "1565476",
-                    "system": "https://pubmed.ncbi.nlm.nih.gov",
+                    "system": "https://pubmed.ncbi.nlm.nih.gov/",
                 },
                 "relation": "relatedMatch",
             },
@@ -318,98 +344,114 @@ def normalized_abl1():
     params = {
         "conceptType": "Gene",
         "id": "normalize.gene.hgnc:76",
-        "primaryCode": "hgnc:76",
-        "label": "ABL1",
+        "primaryCoding": {
+            "id": "hgnc:76",
+            "code": "HGNC:76",
+            "system": "https://www.genenames.org/data/gene-symbol-report/#!/hgnc_id/",
+        },
+        "name": "ABL1",
         "mappings": [
             {
                 "coding": {
-                    "code": "HGNC:76",
-                    "system": "https://www.genenames.org",
+                    "id": "ensembl:ENSG00000097007",
+                    "code": "ENSG00000097007",
+                    "system": "https://www.ensembl.org/id/",
                 },
                 "relation": "exactMatch",
             },
             {
                 "coding": {
-                    "code": "ENSG00000097007",
-                    "system": "https://www.ensembl.org",
-                },
-                "relation": "relatedMatch",
-            },
-            {
-                "coding": {
+                    "id": "ncbigene:25",
                     "code": "25",
                     "system": "https://www.ncbi.nlm.nih.gov/gene/",
                 },
-                "relation": "relatedMatch",
+                "relation": "exactMatch",
             },
             {
                 "coding": {
+                    "id": "vega:OTTHUMG00000020813",
                     "code": "OTTHUMG00000020813",
-                    "system": "https://www.sanger.ac.uk/tool/vega-genome-browser/",
+                    "system": "https://vega.archive.ensembl.org/Homo_sapiens/Gene/Summary?g=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "ucsc:uc004bzv.4",
                     "code": "uc004bzv.4",
-                    "system": "https://genome.ucsc.edu",
+                    "system": "http://genome.cse.ucsc.edu/cgi-bin/hgGene?org=Human&hgg_chrom=none&hgg_type=knownGene&hgg_gene=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "uniprot:P00519",
                     "code": "P00519",
-                    "system": "https://www.uniprot.org",
+                    "system": "http://purl.uniprot.org/uniprot/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "pubmed:1857987",
                     "code": "1857987",
-                    "system": "https://pubmed.ncbi.nlm.nih.gov",
+                    "system": "https://pubmed.ncbi.nlm.nih.gov/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "pubmed:12626632",
                     "code": "12626632",
-                    "system": "https://pubmed.ncbi.nlm.nih.gov",
+                    "system": "https://pubmed.ncbi.nlm.nih.gov/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "cosmic:ABL1",
                     "code": "ABL1",
-                    "system": "https://cancer.sanger.ac.uk/cosmic/",
+                    "system": "http://cancer.sanger.ac.uk/cosmic/gene/overview?ln=",
                 },
                 "relation": "relatedMatch",
             },
             {
-                "coding": {"code": "189980", "system": "https://www.omim.org"},
-                "relation": "relatedMatch",
-            },
-            {
-                "coding": {"code": "117691", "system": "orphanet"},
+                "coding": {
+                    "id": "omim:189980",
+                    "code": "189980",
+                    "system": "https://www.omim.org/MIM:",
+                },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "orphanet:117691",
+                    "code": "117691",
+                    "system": "http://www.orpha.net/consor/cgi-bin/OC_Exp.php?Lng=EN&Expert=",
+                },
+                "relation": "relatedMatch",
+            },
+            {
+                "coding": {
+                    "id": "iuphar:1923",
                     "code": "1923",
-                    "system": "https://www.guidetopharmacology.org",
+                    "system": "https://www.guidetopharmacology.org/GRAC/ObjectDisplayForward?objectId=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "ena.embl:M14752",
                     "code": "M14752",
-                    "system": "https://www.ebi.ac.uk/ena/",
+                    "system": "https://www.ebi.ac.uk/ena/browser/view/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "refseq:NM_007313",
                     "code": "NM_007313",
-                    "system": "https://www.ncbi.nlm.nih.gov/refseq/",
+                    "system": "https://www.ncbi.nlm.nih.gov/nuccore/",
                 },
                 "relation": "relatedMatch",
             },
@@ -486,80 +528,90 @@ def normalized_p150():
     params = {
         "conceptType": "Gene",
         "id": "normalize.gene.hgnc:1910",
-        "primaryCode": "hgnc:1910",
-        "label": "CHAF1A",
+        "primaryCoding": {
+            "id": "hgnc:1910",
+            "code": "HGNC:1910",
+            "system": "https://www.genenames.org/data/gene-symbol-report/#!/hgnc_id/",
+        },
+        "name": "CHAF1A",
         "mappings": [
             {
                 "coding": {
-                    "code": "HGNC:1910",
-                    "system": "https://www.genenames.org",
+                    "id": "ensembl:ENSG00000167670",
+                    "code": "ENSG00000167670",
+                    "system": "https://www.ensembl.org/id/",
                 },
                 "relation": "exactMatch",
             },
             {
                 "coding": {
-                    "code": "ENSG00000167670",
-                    "system": "https://www.ensembl.org",
-                },
-                "relation": "relatedMatch",
-            },
-            {
-                "coding": {
+                    "id": "ncbigene:10036",
                     "code": "10036",
                     "system": "https://www.ncbi.nlm.nih.gov/gene/",
                 },
-                "relation": "relatedMatch",
+                "relation": "exactMatch",
             },
             {
-                "coding": {"code": "601246", "system": "https://www.omim.org"},
+                "coding": {
+                    "id": "omim:601246",
+                    "code": "601246",
+                    "system": "https://www.omim.org/MIM:",
+                },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "ccds:CCDS32875",
                     "code": "CCDS32875",
-                    "system": "https://www.ncbi.nlm.nih.gov/projects/CCDS/CcdsBrowse.cgi",
+                    "system": "http://www.ncbi.nlm.nih.gov/CCDS/CcdsBrowse.cgi?REQUEST=CCDS&DATA=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "pubmed:7600578",
                     "code": "7600578",
-                    "system": "https://pubmed.ncbi.nlm.nih.gov",
+                    "system": "https://pubmed.ncbi.nlm.nih.gov/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "vega:OTTHUMG00000181922",
                     "code": "OTTHUMG00000181922",
-                    "system": "https://www.sanger.ac.uk/tool/vega-genome-browser/",
+                    "system": "https://vega.archive.ensembl.org/Homo_sapiens/Gene/Summary?g=",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "uniprot:Q13111",
                     "code": "Q13111",
-                    "system": "https://www.uniprot.org",
+                    "system": "http://purl.uniprot.org/uniprot/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "refseq:NM_005483",
                     "code": "NM_005483",
-                    "system": "https://www.ncbi.nlm.nih.gov/refseq/",
+                    "system": "https://www.ncbi.nlm.nih.gov/nuccore/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "ena.embl:U20979",
                     "code": "U20979",
-                    "system": "https://www.ebi.ac.uk/ena/",
+                    "system": "https://www.ebi.ac.uk/ena/browser/view/",
                 },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "ucsc:uc002mal.4",
                     "code": "uc002mal.4",
-                    "system": "https://genome.ucsc.edu",
+                    "system": "http://genome.cse.ucsc.edu/cgi-bin/hgGene?org=Human&hgg_chrom=none&hgg_type=knownGene&hgg_gene=",
                 },
                 "relation": "relatedMatch",
             },
@@ -633,17 +685,13 @@ def normalized_loc_653303():
     """
     params = {
         "conceptType": "Gene",
-        "label": "LOC653303",
-        "primaryCode": "ncbigene:653303",
-        "mappings": [
-            {
-                "coding": {
-                    "code": "653303",
-                    "system": "https://www.ncbi.nlm.nih.gov/gene/",
-                },
-                "relation": "exactMatch",
-            },
-        ],
+        "name": "LOC653303",
+        "primaryCoding": {
+            "id": "ncbigene:653303",
+            "code": "653303",
+            "system": "https://www.ncbi.nlm.nih.gov/gene/",
+        },
+        "mappings": [],
         "extensions": [
             {
                 "name": "aliases",
@@ -918,38 +966,42 @@ def normalized_ifnr():
     params = {
         "conceptType": "Gene",
         "id": "normalize.gene.hgnc:5447",
-        "primaryCode": "hgnc:5447",
-        "label": "IFNR",
+        "primaryCoding": {
+            "id": "hgnc:5447",
+            "code": "HGNC:5447",
+            "system": "https://www.genenames.org/data/gene-symbol-report/#!/hgnc_id/",
+        },
+        "name": "IFNR",
         "mappings": [
             {
                 "coding": {
-                    "code": "HGNC:5447",
-                    "system": "https://www.genenames.org",
+                    "id": "ncbigene:3466",
+                    "code": "3466",
+                    "system": "https://www.ncbi.nlm.nih.gov/gene/",
                 },
                 "relation": "exactMatch",
             },
             {
                 "coding": {
-                    "code": "3466",
-                    "system": "https://www.ncbi.nlm.nih.gov/gene/",
-                },
-                "relation": "relatedMatch",
-            },
-            {
-                "coding": {
+                    "id": "pubmed:1906174",
                     "code": "1906174",
-                    "system": "https://pubmed.ncbi.nlm.nih.gov",
+                    "system": "https://pubmed.ncbi.nlm.nih.gov/",
                 },
                 "relation": "relatedMatch",
             },
             {
-                "coding": {"code": "147573", "system": "https://www.omim.org"},
+                "coding": {
+                    "id": "omim:147573",
+                    "code": "147573",
+                    "system": "https://www.omim.org/MIM:",
+                },
                 "relation": "relatedMatch",
             },
             {
                 "coding": {
+                    "id": "pubmed:1193239",
                     "code": "1193239",
-                    "system": "https://pubmed.ncbi.nlm.nih.gov",
+                    "system": "https://pubmed.ncbi.nlm.nih.gov/",
                 },
                 "relation": "relatedMatch",
             },
@@ -1014,7 +1066,7 @@ def compare_normalize_resp(
     assert resp.query == expected_query
     compare_warnings(resp.warnings, expected_warnings)
     assert resp.match_type == expected_match_type
-    assert resp.gene.primaryCode.root == expected_gene.id.split("normalize.gene.")[-1]
+    assert resp.gene.primaryCoding.id == expected_gene.id.split("normalize.gene.")[-1]
     compare_gene(expected_gene, resp.gene)
     if not expected_source_meta:
         assert resp.source_meta_ == {}
@@ -1086,8 +1138,7 @@ def compare_gene(test, actual):
                 loc_id = loc.pop("id")
                 loc_digest = loc.pop("digest")
                 assert loc_id.split("ga4gh:SL.")[-1] == loc_digest
-
-    diff = DeepDiff(actual, test, ignore_order=True)
+    diff = DeepDiff(test, actual, ignore_order=True)
     assert diff == {}, test.id
 
 
